import { Injectable } from '@angular/core';
import { Work } from '../models/work.model';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { NgForm } from '@angular/forms';

@Injectable({
  providedIn: 'root',
})
export class WorkService {
  API_URL = 'http://127.0.0.1:3000';

  private works: Work[] = [];

  constructor(private http: HttpClient) {}

  getWorks(): Observable<any> {
    return this.http.get(`${this.API_URL}/works`);
  }

  getWorkById(id: string): Observable<any> {
    return this.http.get(`${this.API_URL}/works/${id}`);
  }

  //je veux return les works d'un user id
  getWorksByUserId(user_id: string): Observable<any> {
    return this.http.get(`${this.API_URL}/works/${user_id}`);
  }

  //je veux return le link du dernier work d'un user (en l'occurence celui connecté)
  getLastWorkByUserId(user_id: string): Observable<any> {
    return this.http.get(`${this.API_URL}/works/user/${user_id}`);
  }

  postWork(form: NgForm): void {
    let body = {
      link: crypto.randomUUID(),
      user_id: 1,
      id_language: 1,
      code: form.value.content,
      saveDate: new Date(),
    };
    this.http.post<any>(`${this.API_URL}/works`, body).subscribe();
  }

  postWorkCode(code: string): void {
    let body = {
      link: crypto.randomUUID(),
      id_user: 1,
      id_language: 1,
      code: code,
      title: 'Basic JS',
      date: '2024-06-14T13:35:24.756Z',
    };

    this.http.post<any>(`${this.API_URL}/works`, body).subscribe();
  }

  updateWork(id: string, code: string): void {
    let body = {
      newContent: code,
    };
    this.http.put<any>(`${this.API_URL}/works/${id}/content`, body).subscribe();
  }
}
